@@ -78,7 +78,7 @@ octave_midi::create (const std::string &inname, const std::string &outname)
 
   dev = open_midi (inname, outname);
 
-  return true;
+  return dev != 0;
 }
 
 bool
@@ -135,7 +135,7 @@ octave_midi::clone (void) const
 octave_base_value *
 octave_midi::unique_clone (void)
 {
-  count++;
+  OV_COUNT++;
   return this;
 }
 
